@@ -1,8 +1,9 @@
-from typing import List, Tuple, Text, Optional, Dict, Set, Any
+from typing import List, Tuple, Text, Optional, Dict, Any
 
 from spacy_crfsuite.tokenizer import Token
 
 BILOU_PREFIXES = {"B-", "I-", "U-", "L-"}
+NO_ENTITY_TAG = "O"
 
 
 def get_entity_offsets(message: Dict) -> List[Tuple[int, int, Text]]:
@@ -11,7 +12,8 @@ def get_entity_offsets(message: Dict) -> List[Tuple[int, int, Text]]:
     Args:
         message: the message
 
-    Returns: a list of start, end, and tag value tuples
+    Returns:
+        a list of start, end, and tag value tuples
     """
 
     def convert_entity(entity: Dict[Text, Any]) -> Tuple[int, int, Text]:
@@ -22,8 +24,10 @@ def get_entity_offsets(message: Dict) -> List[Tuple[int, int, Text]]:
 
 def bilou_prefix_from_tag(tag: Text) -> Optional[Text]:
     """Returns the BILOU prefix from the given tag.
+
     Args:
         tag: the tag
+
     Returns: the BILOU prefix of the tag
     """
     if tag[:2] in BILOU_PREFIXES:
@@ -33,9 +37,12 @@ def bilou_prefix_from_tag(tag: Text) -> Optional[Text]:
 
 def entity_name_from_tag(tag: Text) -> Text:
     """Remove the BILOU prefix from the given tag.
+
     Args:
         tag: the tag
-    Returns: the tag without the BILOU prefix
+
+    Returns:
+        the tag without the BILOU prefix
     """
     if tag[:2] in BILOU_PREFIXES:
         return tag[2:]
@@ -43,28 +50,25 @@ def entity_name_from_tag(tag: Text) -> Text:
 
 
 def bilou_tags_from_offsets(
-    tokens: List[Token], entities: List[Tuple[int, int, Text]], missing: Text = "O"
+    tokens: List[Token], entities: List[Tuple[int, int, Text]]
 ) -> List[Text]:
     """Creates a list of BILOU tags for the given list of tokens and entities.
+
     Args:
         tokens: the list of tokens
-        entities: the list of start, end, and tag tuples
-        missing: tag for missing entities
-    Returns: a list of BILOU tags
+        entities: the list of start, end, and tag tuples.
+
+    Returns:
+        BILOU tags.
     """
     start_pos_to_token_idx = {token.start: i for i, token in enumerate(tokens)}
     end_pos_to_token_idx = {token.end: i for i, token in enumerate(tokens)}
-    bilou = ["-" for _ in tokens]
+    bilou = [NO_ENTITY_TAG for _ in tokens]
 
-    # Handle entity cases
     _add_bilou_tags_to_entities(
         bilou, entities, end_pos_to_token_idx, start_pos_to_token_idx
     )
 
-    # Now distinguish the O cases from ones where we miss the tokenization
-    entity_positions = _get_entity_positions(entities)
-    _handle_not_an_entity(bilou, tokens, entity_positions, missing)
-
     return bilou
 
 
@@ -89,22 +93,7 @@ def _add_bilou_tags_to_entities(
                 bilou[end_token_idx] = f"L-{label}"
 
 
-def _get_entity_positions(entities: List[Tuple[int, int, Text]]) -> Set[int]:
-    entity_positions = set()
-
-    for start_pos, end_pos, label in entities:
-        for i in range(start_pos, end_pos):
-            entity_positions.add(i)
-
-    return entity_positions
-
-
-def _handle_not_an_entity(
-    bilou: List[Text], tokens: List[Token], entity_positions: Set[int], missing: Text
-):
-    for n, token in enumerate(tokens):
-        for i in range(token.start, token.end):
-            if i in entity_positions:
-                break
-        else:
-            bilou[n] = missing
+def remove_bilou_prefixes(bilou: List[Text]):
+    for i, label in enumerate(bilou):
+        if bilou_prefix_from_tag(label):  # removes BILOU prefix from label
+            bilou[i] = entity_name_from_tag(label)
